const path = require('path');
const { ncp } = require('ncp');
const { exec } = require('child_process');
const { promisify } = require('util');
const asyncExec = promisify(exec);

const frameWorkConfig = {
  express: {
    tools: {
      auth: [
        {
          key: 'passport',
          install: () => {},
        },
      ],
      db: [
        {
          key: 'prisma',
          install: async (destination, dir, spinner) => {
            const addPrismaSetup = async () =>
              new Promise((resolve, reject) => {
                const source = path.join(dir, 'express', 'prisma', 'prisma');
                const options = {
                  clobber: true,
                  stopOnErr: true,
                };

                ncp.limit = 16;
                ncp(
                  source,
                  path.join(destination, 'prisma'),
                  options,
                  function (err) {
                    if (err) reject(err);
                    resolve();
                  }
                );
              });

            const addPrismaInfra = async () =>
              new Promise((resolve, reject) => {
                const source = path.join(dir, 'express', 'prisma', 'infra');
                const options = {
                  clobber: true,
                  stopOnErr: true,
                };

                ncp.limit = 16;
                ncp(
                  source,
                  path.join(destination, 'src', 'infra', 'db'),
                  options,
                  function (err) {
                    if (err) reject(err);
                    resolve();
                  }
                );
              });

            await addPrismaSetup();
            await addPrismaInfra();

            await asyncExec('npm i prisma @prisma/client', {
              cwd: destination,
            });
            await asyncExec('npx prisma generate', { cwd: destination });
          },
        },
      ],
    },
  },
  nextjs: {},
  astro: {},
  react: {},
};

module.exports = { frameWorkConfig };
