const ora = require('ora');
const chalk = require('chalk');

const {
  chooseTemplates,
  copyProjectFiles,
  chooseToolsToWork,
  updatePackageJson,
  validateFramework,
} = require('./templates');
const { installNodeModules } = require('./installation');
const { initGit } = require('./git');

/**
 * @method succeedConsole
 * @description When the project is successful, the console is displayed.
 */
const succeedConsole = async (template, spinner) => {
  spinner.succeed(chalk`{green Complete setup project}`);

  const msg = '⛰ Installation Completed!';

  msg && console.log(msg);
};

/**
 * @method failConsole
 * @description When the project is fail, the console is displayed.
 */
const failConsole = async (error, spinner) => {
  spinner.fail(
    chalk`{red ${
      error && error.message ? error.message : 'Sorry but ocurred an error'
    }}`
  );
};

/**
 * @method createProject
 * @description Create a project
 */
const createProject = async (projectName) => {
  let spinner;

  try {
    const template = await chooseTemplates();
    spinner = ora();
    spinner.start();

    validateFramework(template);

    console.log('[ 1 / 4 ] 🔍  copying project...');
    await copyProjectFiles(projectName, template);

    console.log('[ 2 / 4 ] 🔍  update package json...');
    await updatePackageJson(projectName);

    console.log('[ 3 / 4 ] 🚚  fetching node_modules...');
    await installNodeModules(projectName, spinner);
    await initGit(projectName);

    console.log('[ 4 / 4 ] 🔗  Adding options to your template...');
    console.log(
      '\u001b[2m──────────────────────────────────────────\u001b[22m'
    );
    await chooseToolsToWork(template, spinner, projectName);

    await succeedConsole(template, spinner);
  } catch (error) {
    await failConsole(error, spinner);
  }
};

module.exports = { createProject };
