import { config } from 'dotenv';
import env from 'env-var';

config({ path: `.env.${process.env.NODE_ENV || 'development'}.local` });

const LOG_CONFIG = {
  LOG_FORMAT: env.get('LOG_FORMAT').required().asString(),
  LOG_DIR: env.get('LOG_DIR').required().asString(),
};

const CORS_CONFIG = {
  ORIGIN: env.get('ORIGIN').required().asString(),
  CREDENTIALS: env.get('CREDENTIALS').required().asString() === 'true',
};

const DB_CONFIG = {
  POSTGRES_URL: env.get('POSTGRES_URL').required().asString(),
  POSTGRES_DB: env.get('POSTGRES_DB').required().asString(),
  POSTGRES_USER: env.get('POSTGRES_USER').required().asString(),
  POSTGRES_PASSWORD: env.get('POSTGRES_PASSWORD').required().asString(),
  POSTGRES_PORTLOCAL: env.get('POSTGRES_PORTLOCAL').required().asString(),
  POSTGRES_PORT: env.get('POSTGRES_PORT').required().asString(),
};

const AUTH_CONFIG = {
  JWT_SECRET: env.get('JWT_SECRET').required().asString(),
  JWT_ACCESS_TOKEN_EXPIRATION: env.get('JWT_ACCESS_TOKEN_EXPIRATION').required().asString(),
  JWT_REFRESH_TOKEN_EXPIRATION: env.get('JWT_REFRESH_TOKEN_EXPIRATION').required().asString(),
  JWT_REFRESH_TOKEN_EXPIRATION_AT_SECONDS: env.get('JWT_REFRESH_TOKEN_EXPIRATION_AT_SECONDS').required().asIntPositive(),
};

export const envs = {
  PORT: env.get('PORT').required().asPortNumber(),
  NODE_ENV: env.get('NODE_ENV').required().asString(),

  ...AUTH_CONFIG,
  ...CORS_CONFIG,
  ...LOG_CONFIG,
  ...DB_CONFIG,
};
